# Metadata

Metadata defines subgroup properties of metav1.ObjectMeta
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**annotations** | **dict(str, str)** | Annotations are annotations of pod specification | [optional] 
**labels** | **dict(str, str)** | Labels are labels of pod specification | [optional] 
**selector** | [**V1GroupKind**](V1GroupKind.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


